@@ -153,13 +153,15 @@ class AIServiceClass():
             os.remove(img)
         return resultData
 
-    def img_contain_text(self, img, text, lang='chi_sim'):
+    def img_contain_text(self, img, text, lang='chi_sim', isShowContent=False):
         '''
         图片是否包含文字
         return bool
         '''
         resultStr = image_to_string(img, lang=lang)
         resultStr = resultStr.replace('\n', '').replace(' ', '')
+        if isShowContent:
+            print(resultStr)
         if type(text) == type([]):
             for item in text[:]:
                 if item in resultStr:
@@ -169,7 +171,7 @@ class AIServiceClass():
                 return True
         return False
 
-    def img_contain_text_jieba(self, img, text, lang='chi_sim', confidence=None, cut_all=False):
+    def img_contain_text_jieba(self, img, text, lang='chi_sim', confidence=None, cut_all=False, isShowContent=False):
         '''
         图片是否包含某一句话（结巴）
         confidence 匹配度
@@ -180,7 +182,9 @@ class AIServiceClass():
             return 0
         resultStr = image_to_string(img, lang=lang)
         resultStr = resultStr.replace('\n', '').replace(' ', '')
-        used, sum = 0, 0
+        if isShowContent:
+            print(resultStr)
+        used, sum = 1, 1
         for item in seg_list:
             if item[0] in resultStr:
                 used += 1
