@@ -5,13 +5,14 @@ from apscheduler.schedulers.background import BackgroundScheduler
 #https://www.jianshu.com/p/4f5305e220f0
 
 class APSchedulerServiceClass():
-    def __init__(self):
+    def __init__(self, showLog = False):
         self.blockingScheduler = BlockingScheduler()
         self.backgroundScheduler = BackgroundScheduler()
         self.blockingRecodeDic = {}
         self.backgroundRecodeDic = {}
         self.blockingRecodeIndex = 0
         self.backgroundRecodeIndex = 0
+        self.showLog = showLog
 
     def AddJob_FixedTime(self, job_function, run_date, args=None, kwargs=None, timezone=None, isBackground=True, jobId=None):
         '''
@@ -99,11 +100,11 @@ class APSchedulerServiceClass():
                         self.backgroundScheduler.remove_job(item)
                 self.backgroundScheduler.remove_all_jobs()
                 self.backgroundRecodeDic.clear()
-                print("移除all：%s"%isAll)
+                _Log("移除all：%s"%isAll)
             else:
                 self.backgroundScheduler.remove_job(jobId)
                 self.backgroundRecodeDic.pop(jobId)
-                print("移除jobId：%s"%jobId)
+                _Log("移除jobId：%s"%jobId)
             self.backgroundScheduler.print_jobs()
         else:
             if isAll:
@@ -112,11 +113,11 @@ class APSchedulerServiceClass():
                         self.blockingScheduler.remove_job(item)
                 self.blockingScheduler.remove_all_jobs()
                 self.blockingRecodeDic.clear()
-                print("移除all：%s"%isAll)
+                _Log("移除all：%s"%isAll)
             else:
                 self.blockingScheduler.remove_job(jobId)
                 self.blockingRecodeDic.pop(jobId)
-                print("移除jobId：%s"%jobId)
+                _Log("移除jobId：%s"%jobId)
             self.blockingScheduler.print_jobs()
     
     def PauseJob(self, jobId='', isAll=False, isBackground=True):
@@ -162,13 +163,13 @@ class APSchedulerServiceClass():
             if not self.backgroundScheduler.running:
                 self.backgroundScheduler.start()
             else:
-                print("backgroundScheduler 正在运行")
+                _Log("backgroundScheduler 正在运行")
                 self.backgroundScheduler.print_jobs()
         if isRunBlockingScheduler:
             if not self.blockingScheduler.running:
                 self.blockingScheduler.start()
             else:
-                print("blockingScheduler 正在运行")
+                _Log("blockingScheduler 正在运行")
                 self.blockingScheduler.print_jobs()
     
     def _CheckGetSchedAndId(self, isBackground=True, jobId=None):
@@ -208,6 +209,9 @@ class APSchedulerServiceClass():
             self.blockingRecodeDic[jobId] = job
         return (jobId, job)
 
+    def _Log(self, value):
+        if self.showLog:
+            print(value)
 
 if __name__ == "__main__":
     def Test(x):
