@@ -33,15 +33,15 @@ class FileServiceClass(object):
     def GetFiles(self, dirPath, isCurrDir, excludeList = []):
         filesTemp = []
         for root, dirs, files in os.walk(dirPath):
-            for file in files:
+            for filePath in files:
                 isAppend = False
                 if isCurrDir:
                     if root == dirPath:
                         isAppend = True
                 else:
                     isAppend = True
-                if isAppend and not file in excludeList:
-                    filesTemp.append(os.path.join(root, file))
+                if isAppend and not filePath in excludeList:
+                    filesTemp.append(os.path.join(root, filePath))
             if isCurrDir and root == dirPath:
                 break
         return filesTemp
