@@ -21,4 +21,15 @@ class RegexServiceClass(object):
         for x in result:
             print(x)
         '''
-        return result
\ No newline at end of file
+        return result
+    
+    # 正则获取IP地址
+    def GetRegexIP(self, content):
+        reip = re.compile(r'(?<![\.\d])(?:\d{1,3}\.){3}\d{1,3}(?![\.\d])')
+        return reip.findall(content)
+    
+    # 正则截断字符串【按照指定长度】
+    def GetCutText(self, text, lenth):
+        textArr = re.findall('.{'+str(lenth)+'}', text)
+        textArr.append(text[(len(textArr)*lenth):])
+        return textArr
\ No newline at end of file
